@@ -18,7 +18,7 @@ from humanfriendly import format_timespan
 
 
 __author__ = 'Erik Moqvist'
-__version__ = '5.9.0'
+__version__ = '5.10.0'
 
 
 _RUN_HEADER_FMT ='''
@@ -216,11 +216,6 @@ class TestCaseXFailedError(Exception):
     pass
 
 
-# Deprecated. To be removed.
-SequencerTestFailedError = TestCaseFailedError
-SequencerTestSkippedError = TestCaseSkippedError
-
-
 class TestCase(object):
     """Base class of a test case executed by the sequencer.
 
